Your task is to extend given CSV by understanding underlying relations of columns and adding new rows which are more diverse. 

You will be given a seed column value, use that value to extend the CSV. Only output your new rows in csv format.

Example format

```csv
Communication, Email, Read the contents of an email
Communication, Email, Retrieve the last n emails
Scheduling, To-Do List, Create a task
```

here is the csv
{{csv}}

here is the seed column value 
{{seed_column}}

Only output new rows of csv and nothing else. 
Output:
